---
slug: /error-code-overview
---

# Error message overview

This chapter describes the error messages in seekdb.

## Error message format

seekdb is highly compatible with MySQL, not only in terms of common MySQL features and protocols, but also in its native error messages. Therefore, the error message format in seekdb is consistent with that of MySQL.

The error message format is as follows:

```shell
ERROR <err_num> (<sql_stat>) : err_msg
```

The parameters are described as follows:

* `err_num` indicates the error code.

* `sql_stat` indicates the SQL state.

* `err_msg` indicates the error message.

## Variables in error messages

To help you identify and resolve errors, seekdb embeds parameters in the error messages. In this chapter, these parameters are displayed with a percent sign (%).

Here is an example:

```shell
ERROR 5235 (HY000) : The table \'%.*s.%.*s\' is read only so it cannot execute this statement
```

The message may actually be displayed as follows:

```shell
ERROR 5235 (HY000) : The table 'testdb' is read only so it cannot execute this statement
```

## Error message list

The following table describes the system error code ranges and their corresponding error messages.

| Error code range | Description |
|---------------------|-------------------------|
| [0001 \~ 3999](200.0001-3999.md)            | Error messages compatible with MySQL. <br/>For more information about MySQL server error codes, see [Server Error Message Reference](https://dev.mysql.com/doc/mysql-errors/8.0/en/server-error-reference.html). <br/>For more information about MySQL client error codes, see [Client Error Message Reference](https://dev.mysql.com/doc/mysql-errors/8.0/en/client-error-reference.html). |
| [4000 \~ 4499](300.4000-4499.md)            | General error codes.   |
| [5000 \~ 5999](500.5000-5999.md)            | Error codes for SQL, WITH clauses, and factoring.     |
| [6000 \~ 6999](600.6000-6999.md)            | Error codes for transactions, MVCC, and clogs.  |
| [8000 \~ 8999](800.8000-8999.md)            | Fatal errors. When a client receives an error in this range, it must close the SQL connection.        |
| [9500 \~ 9999](1000.9500-9999.md)            | Error codes for procedural languages (PL).  |
| [22998, 30926, 38104, 38105](1100.22998-30926-38104-38105.md) | Error codes for BLOB/CLOB. |